@@ -18,14 +18,18 @@
 """Pool APIs."""
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 from deprecated import deprecated
 from sqlalchemy import select
-from sqlalchemy.orm import Session
 
 from airflow.exceptions import AirflowBadRequest, PoolNotFound
 from airflow.models import Pool
 from airflow.utils.session import NEW_SESSION, provide_session
 
+if TYPE_CHECKING:
+    from sqlalchemy.orm import Session
+
 
 @deprecated(reason="Use Pool.get_pool() instead", version="2.2.4")
 @provide_session
@@ -45,7 +49,7 @@ def get_pool(name, session: Session = NEW_SESSION):
 @provide_session
 def get_pools(session: Session = NEW_SESSION):
     """Get all pools."""
-    return session.query(Pool).all()
+    return session.scalars(select(Pool)).all()
 
 
 @deprecated(reason="Use Pool.create_pool() instead", version="2.2.4")
