@@ -26,10 +26,9 @@ import signal
 import subprocess
 import sys
 import warnings
+from typing import TYPE_CHECKING
 
-from graphviz.dot import Dot
 from sqlalchemy import delete, select
-from sqlalchemy.orm import Session
 
 from airflow import settings
 from airflow.api.client import get_current_api_client
@@ -41,7 +40,6 @@ from airflow.jobs.job import Job
 from airflow.models import DagBag, DagModel, DagRun, TaskInstance
 from airflow.models.dag import DAG
 from airflow.models.serialized_dag import SerializedDagModel
-from airflow.timetables.base import DataInterval
 from airflow.utils import cli as cli_utils, timezone
 from airflow.utils.cli import get_dag, get_dags, process_subdir, sigint_handler, suppress_logs_and_warning
 from airflow.utils.dot_renderer import render_dag, render_dag_dependencies
@@ -49,6 +47,12 @@ from airflow.utils.providers_configuration_loader import providers_configuration
 from airflow.utils.session import NEW_SESSION, create_session, provide_session
 from airflow.utils.state import DagRunState
 
+if TYPE_CHECKING:
+    from graphviz.dot import Dot
+    from sqlalchemy.orm import Session
+
+    from airflow.timetables.base import DataInterval
+
 log = logging.getLogger(__name__)
 
 
@@ -316,14 +320,14 @@ def dag_next_execution(args) -> None:
     """
     dag = get_dag(args.subdir, args.dag_id)
 
-    if dag.get_is_paused():
-        print("[INFO] Please be reminded this DAG is PAUSED now.", file=sys.stderr)
-
     with create_session() as session:
         last_parsed_dag: DagModel = session.scalars(
             select(DagModel).where(DagModel.dag_id == dag.dag_id)
         ).one()
 
+    if last_parsed_dag.get_is_paused():
+        print("[INFO] Please be reminded this DAG is PAUSED now.", file=sys.stderr)
+
     def print_execution_interval(interval: DataInterval | None):
         if interval is None:
             print(
@@ -405,6 +409,8 @@ def dag_list_import_errors(args) -> None:
         data=data,
         output=args.output,
     )
+    if data:
+        sys.exit(1)
 
 
 @cli_utils.action_cli
