@@ -19,9 +19,7 @@ from __future__ import annotations
 from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
-import boto3
-
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowSkipException
 from airflow.providers.amazon.aws.hooks.ecs import (
     EcsClusterStates,
     EcsHook,
@@ -31,16 +29,20 @@ from airflow.providers.amazon.aws.hooks.ecs import (
 from airflow.sensors.base import BaseSensorOperator
 
 if TYPE_CHECKING:
+    import boto3
+
     from airflow.utils.context import Context
 
 DEFAULT_CONN_ID: str = "aws_default"
 
 
-def _check_failed(current_state, target_state, failure_states):
+def _check_failed(current_state, target_state, failure_states, soft_fail: bool) -> None:
     if (current_state != target_state) and (current_state in failure_states):
-        raise AirflowException(
-            f"Terminal state reached. Current state: {current_state}, Expected state: {target_state}"
-        )
+        # TODO: remove this if block when min_airflow_version is set to higher than 2.7.1
+        message = f"Terminal state reached. Current state: {current_state}, Expected state: {target_state}"
+        if soft_fail:
+            raise AirflowSkipException(message)
+        raise AirflowException(message)
 
 
 class EcsBaseSensor(BaseSensorOperator):
@@ -95,7 +97,7 @@ class EcsClusterStateSensor(EcsBaseSensor):
         cluster_state = EcsClusterStates(self.hook.get_cluster_state(cluster_name=self.cluster_name))
 
         self.log.info("Cluster state: %s, waiting for: %s", cluster_state, self.target_state)
-        _check_failed(cluster_state, self.target_state, self.failure_states)
+        _check_failed(cluster_state, self.target_state, self.failure_states, self.soft_fail)
 
         return cluster_state == self.target_state
 
@@ -141,7 +143,7 @@ class EcsTaskDefinitionStateSensor(EcsBaseSensor):
         )
 
         self.log.info("Task Definition state: %s, waiting for: %s", task_definition_state, self.target_state)
-        _check_failed(task_definition_state, self.target_state, [self.failure_states])
+        _check_failed(task_definition_state, self.target_state, [self.failure_states], self.soft_fail)
         return task_definition_state == self.target_state
 
 
@@ -181,5 +183,5 @@ class EcsTaskStateSensor(EcsBaseSensor):
         task_state = EcsTaskStates(self.hook.get_task_state(cluster=self.cluster, task=self.task))
 
         self.log.info("Task state: %s, waiting for: %s", task_state, self.target_state)
-        _check_failed(task_state, self.target_state, self.failure_states)
+        _check_failed(task_state, self.target_state, self.failure_states, self.soft_fail)
         return task_state == self.target_state
