@@ -18,7 +18,7 @@ from __future__ import annotations
 
 import logging
 import re
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 
 from airflow.utils.helpers import prune_dict
@@ -55,14 +55,21 @@ def datetime_to_epoch_ms(date_time: datetime) -> int:
     return int(date_time.timestamp() * 1_000)
 
 
+def datetime_to_epoch_utc_ms(date_time: datetime) -> int:
+    """Convert a datetime object to an epoch integer (milliseconds) in UTC timezone."""
+    return int(date_time.replace(tzinfo=timezone.utc).timestamp() * 1_000)
+
+
 def datetime_to_epoch_us(date_time: datetime) -> int:
     """Convert a datetime object to an epoch integer (microseconds)."""
     return int(date_time.timestamp() * 1_000_000)
 
 
 def get_airflow_version() -> tuple[int, ...]:
-    val = re.sub(r"(\d+\.\d+\.\d+).*", lambda x: x.group(1), version)
-    return tuple(int(x) for x in val.split("."))
+    match = re.match(r"(\d+)\.(\d+)\.(\d+)", version)
+    if match is None:  # Not theoratically possible.
+        raise RuntimeError(f"Broken Airflow version: {version}")
+    return tuple(int(x) for x in match.groups())
 
 
 class _StringCompareEnum(Enum):
