@@ -15,7 +15,7 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Hook for Google Cloud Life Sciences service"""
+"""Hook for Google Cloud Life Sciences service."""
 from __future__ import annotations
 
 import time
@@ -25,7 +25,7 @@ from typing import Sequence
 import google.api_core.path_template
 from googleapiclient.discovery import build
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
 # Time to sleep between active checks of the operation results
@@ -36,14 +36,16 @@ class LifeSciencesHook(GoogleBaseHook):
     """
     Hook for the Google Cloud Life Sciences APIs.
 
+    .. warning::
+        This hook is deprecated. Consider using Google Cloud Batch Operators' hook instead.
+        The Life Sciences API (beta) will be discontinued on July 8, 2025 in favor
+        of Google Cloud Batch.
+
     All the methods in the hook where project_id is used must be called with
     keyword arguments rather than positional.
 
     :param api_version: API version used (for example v1 or v1beta1).
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -60,20 +62,28 @@ class LifeSciencesHook(GoogleBaseHook):
         self,
         api_version: str = "v2beta",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
             )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self.api_version = api_version
 
+        warnings.warn(
+            """This hook is deprecated. Consider using Google Cloud Batch Operators' hook instead.
+            The Life Sciences API (beta) will be discontinued on July 8, 2025 in favor
+            of Google Cloud Batch.""",
+            AirflowProviderDeprecationWarning,
+            stacklevel=3,
+        )
+
     def get_conn(self) -> build:
         """
         Retrieves the connection to Cloud Life Sciences.
@@ -88,7 +98,7 @@ class LifeSciencesHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def run_pipeline(self, body: dict, location: str, project_id: str) -> dict:
         """
-        Runs a pipeline
+        Runs a pipeline.
 
         :param body: The request body.
         :param location: The location of the project. For example: "us-east1".
@@ -126,8 +136,7 @@ class LifeSciencesHook(GoogleBaseHook):
 
     def _wait_for_operation_to_complete(self, operation_name: str) -> None:
         """
-        Waits for the named operation to complete - checks status of the
-        asynchronous call.
+        Waits for the named operation to complete - checks status of the asynchronous call.
 
         :param operation_name: The name of the operation.
         :return: The response returned by the operation.
