@@ -18,14 +18,16 @@
 from __future__ import annotations
 
 import warnings
-from typing import Iterable
+from typing import TYPE_CHECKING, Iterable
 
 from airflow.exceptions import RemovedInAirflow3Warning
 from airflow.sensors.base import BaseSensorOperator
 from airflow.utils import timezone
-from airflow.utils.context import Context
 from airflow.utils.weekday import WeekDay
 
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
+
 
 class DayOfWeekSensor(BaseSensorOperator):
     """
