@@ -252,7 +252,6 @@ class ExecutorConfigType(PickleType):
     cache_ok = True
 
     def bind_processor(self, dialect):
-
         from airflow.serialization.serialized_objects import BaseSerialization
 
         super_process = super().bind_processor(dialect)
@@ -438,7 +437,7 @@ def lock_rows(query: Query, session: Session) -> Generator[None, None, None]:
 
     :meta private:
     """
-    locked_rows = with_row_locks(query, session).all()
+    locked_rows = with_row_locks(query, session)
     yield
     del locked_rows
 
@@ -592,7 +591,9 @@ def tuple_not_in_condition(
 
     :meta private:
     """
-    if settings.engine.dialect.name != "mssql":
+    dialect = session.bind.dialect if session else settings.engine.dialect
+
+    if dialect.name != "mssql":
         return tuple_(*columns).not_in(collection)
     if not isinstance(collection, Select):
         rows = collection
