@@ -22,7 +22,7 @@ import gzip
 import itertools
 import json
 import logging
-from io import BytesIO as IO
+from io import BytesIO
 from typing import Callable, TypeVar, cast
 
 import pendulum
@@ -78,7 +78,7 @@ def _mask_connection_fields(extra_fields):
 
 
 def action_logging(func: Callable | None = None, event: str | None = None) -> Callable[[T], T]:
-    """Decorator to log user actions."""
+    """Log user actions."""
 
     def log_action(f: T) -> T:
         @functools.wraps(f)
@@ -88,8 +88,10 @@ def action_logging(func: Callable | None = None, event: str | None = None) -> Ca
             with create_session() as session:
                 if not get_auth_manager().is_logged_in():
                     user = "anonymous"
+                    user_display = ""
                 else:
                     user = get_auth_manager().get_user_name()
+                    user_display = get_auth_manager().get_user_display_name()
 
                 fields_skip_logging = {"csrf_token", "_csrf_token"}
                 extra_fields = [
@@ -108,6 +110,7 @@ def action_logging(func: Callable | None = None, event: str | None = None) -> Ca
                     event=event or f.__name__,
                     task_instance=None,
                     owner=user,
+                    owner_display_name=user_display,
                     extra=str(extra_fields),
                     task_id=params.get("task_id"),
                     dag_id=params.get("dag_id"),
@@ -134,7 +137,7 @@ def action_logging(func: Callable | None = None, event: str | None = None) -> Ca
 
 
 def gzipped(f: T) -> T:
-    """Decorator to make a view compressed."""
+    """Make a view compressed."""
 
     @functools.wraps(f)
     def view_func(*args, **kwargs):
@@ -153,12 +156,10 @@ def gzipped(f: T) -> T:
                 or "Content-Encoding" in response.headers
             ):
                 return response
-            gzip_buffer = IO()
-            gzip_file = gzip.GzipFile(mode="wb", fileobj=gzip_buffer)
-            gzip_file.write(response.data)
-            gzip_file.close()
-
-            response.data = gzip_buffer.getvalue()
+            with BytesIO() as gzip_buffer:
+                with gzip.GzipFile(mode="wb", fileobj=gzip_buffer) as gzip_file:
+                    gzip_file.write(response.data)
+                response.data = gzip_buffer.getvalue()
             response.headers["Content-Encoding"] = "gzip"
             response.headers["Vary"] = "Accept-Encoding"
             response.headers["Content-Length"] = len(response.data)
